{
  config,
  pkgs,
  lib,
  ...
}: {
  # Server-specific home configuration
  
  # Server-specific packages
  home.packages = with pkgs; [
    tmux
    htop
    iotop
    iftop
    nmap
  ];
  
  # Tmux configuration
  programs.tmux = {
    enable = true;
    clock24 = true;
    historyLimit = 10000;
    terminal = "screen-256color";
    
    plugins = with pkgs.tmuxPlugins; [
      sensible
      yank
      resurrect
      continuum
    ];
    
    extraConfig = ''
      # Enable mouse mode
      set -g mouse on
      
      # Start windows and panes at 1, not 0
      set -g base-index 1
      setw -g pane-base-index 1
      
      # Set status bar
      set -g status-style 'bg=#333333 fg=#5eacd3'
    '';
  };
  
  # Vim configuration for server use
  programs.neovim = {
    enable = true;
    defaultEditor = true;
    viAlias = true;
    vimAlias = true;
    
    plugins = with pkgs.vimPlugins; [
      vim-nix
      vim-sensible
      vim-fugitive
      vim-surround
    ];
    
    extraConfig = ''
      set number
      set relativenumber
      set tabstop=2
      set shiftwidth=2
      set expandtab
      set smartindent
      set ignorecase
      set smartcase
    '';
  };
} 