{
    pkgs,
    lib,
    ...
}: {
    users.users.laurent = {
        isNormalUser = true;
        description = "laurent";
        extraGroups = [ "networkmanager" "wheel" ];
        shell = pkgs.zsh;
    };

    nix.settings = {
        experimental-features = [ "nix-command" "flakes" ];
    };

    nix.gc = {
        automatic = lib.mkDefault true;
        dates = lib.mkDefault "weekly";
        options = lib.mkDefault "--delete-older-than 7d";
    };

    nix.optimise = {
        automatic = lib.mkDefault true;
        dates = lib.mkDefault [ "weekly" ];
    };

    nixpkgs.config.allowUnfree = true;

    time.timeZone = "Indian/Reunion";

    console.keyMap = "fr";
    i18n = {
        defaultLocale = "fr_FR.UTF-8";
        extraLocaleSettings = {
            LC_ADDRESS = "fr_FR.UTF-8";
            LC_IDENTIFICATION = "fr_FR.UTF-8";
            LC_MEASUREMENT = "fr_FR.UTF-8";
            LC_MONETARY = "fr_FR.UTF-8";
            LC_NAME = "fr_FR.UTF-8";
            LC_NUMERIC = "fr_FR.UTF-8";
            LC_PAPER = "fr_FR.UTF-8";
            LC_TELEPHONE = "fr_FR.UTF-8";
            LC_TIME = "fr_FR.UTF-8";
        };
    };

    services.printing.enable = true;
    
    environment.systemPackages = with pkgs; [
        git
        vim
        wget
        pavucontrol
        eza
        zoxide
        btop
        fzf
        ripgrep
    ];

    fonts = {
        packages = with pkgs; [
            nerd-fonts.fira-code
            noto-fonts
            noto-fonts-cjk-sans
            noto-fonts-emoji
        ];
        fontconfig = {
            defaultFonts = {
                serif = [ "Noto Serif" ];
                sansSerif = [ "Noto Sans" ];
                monospace = [ "FiraCode Nerd Font Mono" ];
            };
        };
    };

    programs.zsh.enable = true;
} 